package
Version:
v0.1.12
Opens a new window with list of versions in this module.
Published: Mar 23, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
type Pair
-
type Triple
-
func (t Triple[R, T, U]) First() R
-
func (p Triple[R, T, U]) MarshalJSON() ([]byte, error)
-
func (t Triple[R, T, U]) Second() T
-
func (p Triple[R, T, U]) String() string
-
func (t Triple[R, T, U]) Third() U
type Pair[T any, U any] struct {
}
func NewPair[T any, U any](first T, second U) *Pair[T, U]
func (t Pair[T, U]) First() T
MarshalJSON implements the json.Marshaler interface.
It requires T and U to be json.Marshaler or basic types that can be marshaled.
func (t Pair[T, U]) Second() U
String implements the fmt.Stringer interface.
It uses fmt.Sprintf to convert the values to strings.
func NewTriple[R any, T any, U any](first R, second T, third U) *Triple[R, T, U]
func (t Triple[R, T, U]) First() R
MarshalJSON implements the json.Marshaler interface.
It requires R, T and U to be json.Marshaler or basic types that can be marshaled.
func (t Triple[R, T, U]) Second() T
String implements the fmt.Stringer interface.
It uses fmt.Sprintf to convert the values to strings.
func (t Triple[R, T, U]) Third() U
Source Files
¶
Click to show internal directories.
Click to hide internal directories.